@@ -57,7 +57,7 @@ class select_geoms:
                     data.crs = {'init': 'epsg:3857'}
                 check_topology(data)
             except ValueError:
-                datad = gpd.read_file([i for i in glob.glob(f"{self.gdf_path}/*.shp")]).to_crs({'init': 'epsg:3857'})
+                datad = gpd.read_file(self.gdf_path).to_crs({'init': 'epsg:3857'})
                 data = datad.copy().to_crs({'init': 'epsg:3857'})
                 if data.crs == None:
                     data.crs = {'init': 'epsg:3857'}
